# This file was auto-generated by Fern from our API Definition.

import typing

from .input_message_content_item import InputMessageContentItem

Content = typing.Union[str, typing.List[InputMessageContentItem]]
